# Bionty: Manage biological entities

This package is in private beta at this moment!

Follow https://twitter.com/laminlabs to learn about a first public release.

For beta users: Read the [docs](https://lamin.ai/bionty).
